@@ -25,80 +25,69 @@ class DeleteRuleRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'UniMkt', '2018-12-12', 'DeleteRule')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_MessageKey(self):
+	def get_MessageKey(self): # String
 		return self.get_query_params().get('MessageKey')
 
-	def set_MessageKey(self,MessageKey):
-		self.add_query_param('MessageKey',MessageKey)
-
-	def get_AdRule(self):
+	def set_MessageKey(self, MessageKey):  # String
+		self.add_query_param('MessageKey', MessageKey)
+	def get_AdRule(self): # String
 		return self.get_body_params().get('AdRule')
 
-	def set_AdRule(self,AdRule):
+	def set_AdRule(self, AdRule):  # String
 		self.add_body_params('AdRule', AdRule)
-
-	def get_Business(self):
+	def get_Business(self): # String
 		return self.get_query_params().get('Business')
 
-	def set_Business(self,Business):
-		self.add_query_param('Business',Business)
-
-	def get_Message(self):
+	def set_Business(self, Business):  # String
+		self.add_query_param('Business', Business)
+	def get_Message(self): # String
 		return self.get_query_params().get('Message')
 
-	def set_Message(self,Message):
-		self.add_query_param('Message',Message)
-
-	def get_UserId(self):
+	def set_Message(self, Message):  # String
+		self.add_query_param('Message', Message)
+	def get_UserId(self): # String
 		return self.get_query_params().get('UserId')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_OriginSiteUserId(self):
+	def set_UserId(self, UserId):  # String
+		self.add_query_param('UserId', UserId)
+	def get_OriginSiteUserId(self): # String
 		return self.get_query_params().get('OriginSiteUserId')
 
-	def set_OriginSiteUserId(self,OriginSiteUserId):
-		self.add_query_param('OriginSiteUserId',OriginSiteUserId)
-
-	def get_Environment(self):
+	def set_OriginSiteUserId(self, OriginSiteUserId):  # String
+		self.add_query_param('OriginSiteUserId', OriginSiteUserId)
+	def get_Environment(self): # String
 		return self.get_query_params().get('Environment')
 
-	def set_Environment(self,Environment):
-		self.add_query_param('Environment',Environment)
-
-	def get_AppName(self):
+	def set_Environment(self, Environment):  # String
+		self.add_query_param('Environment', Environment)
+	def get_AppName(self): # String
 		return self.get_query_params().get('AppName')
 
-	def set_AppName(self,AppName):
-		self.add_query_param('AppName',AppName)
-
-	def get_TenantId(self):
+	def set_AppName(self, AppName):  # String
+		self.add_query_param('AppName', AppName)
+	def get_TenantId(self): # String
 		return self.get_query_params().get('TenantId')
 
-	def set_TenantId(self,TenantId):
-		self.add_query_param('TenantId',TenantId)
-
-	def get_UserSite(self):
+	def set_TenantId(self, TenantId):  # String
+		self.add_query_param('TenantId', TenantId)
+	def get_UserSite(self): # String
 		return self.get_query_params().get('UserSite')
 
-	def set_UserSite(self,UserSite):
-		self.add_query_param('UserSite',UserSite)
-
-	def get_RuleId(self):
+	def set_UserSite(self, UserSite):  # String
+		self.add_query_param('UserSite', UserSite)
+	def get_RuleId(self): # String
 		return self.get_query_params().get('RuleId')
 
-	def set_RuleId(self,RuleId):
-		self.add_query_param('RuleId',RuleId)
-
-	def get_Status(self):
+	def set_RuleId(self, RuleId):  # String
+		self.add_query_param('RuleId', RuleId)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
