@@ -25,26 +25,24 @@ class EndUnionTaskRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'UniMkt', '2018-12-12', 'EndUnionTask')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ProxyUserId(self):
+	def get_ProxyUserId(self): # Long
 		return self.get_query_params().get('ProxyUserId')
 
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
-
-	def get_ChannelId(self):
+	def set_ProxyUserId(self, ProxyUserId):  # Long
+		self.add_query_param('ProxyUserId', ProxyUserId)
+	def get_ChannelId(self): # String
 		return self.get_query_params().get('ChannelId')
 
-	def set_ChannelId(self,ChannelId):
-		self.add_query_param('ChannelId',ChannelId)
-
-	def get_TaskId(self):
+	def set_ChannelId(self, ChannelId):  # String
+		self.add_query_param('ChannelId', ChannelId)
+	def get_TaskId(self): # Long
 		return self.get_query_params().get('TaskId')
 
-	def set_TaskId(self,TaskId):
-		self.add_query_param('TaskId',TaskId)
\ No newline at end of file
+	def set_TaskId(self, TaskId):  # Long
+		self.add_query_param('TaskId', TaskId)
