@@ -25,38 +25,39 @@ class GetUnionTaskStatusRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'UniMkt', '2018-12-12', 'GetUnionTaskStatus')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_UserNick(self):
+	def get_UserNick(self): # String
 		return self.get_query_params().get('UserNick')
 
-	def set_UserNick(self,UserNick):
-		self.add_query_param('UserNick',UserNick)
-
-	def get_Sign(self):
+	def set_UserNick(self, UserNick):  # String
+		self.add_query_param('UserNick', UserNick)
+	def get_Sign(self): # String
 		return self.get_query_params().get('Sign')
 
-	def set_Sign(self,Sign):
-		self.add_query_param('Sign',Sign)
-
-	def get_AlipayOpenId(self):
+	def set_Sign(self, Sign):  # String
+		self.add_query_param('Sign', Sign)
+	def get_AlipayOpenId(self): # Long
 		return self.get_query_params().get('AlipayOpenId')
 
-	def set_AlipayOpenId(self,AlipayOpenId):
-		self.add_query_param('AlipayOpenId',AlipayOpenId)
-
-	def get_UserId(self):
+	def set_AlipayOpenId(self, AlipayOpenId):  # Long
+		self.add_query_param('AlipayOpenId', AlipayOpenId)
+	def get_UserId(self): # Long
 		return self.get_query_params().get('UserId')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_TaskId(self):
+	def set_UserId(self, UserId):  # Long
+		self.add_query_param('UserId', UserId)
+	def get_TaskId(self): # Long
 		return self.get_query_params().get('TaskId')
 
-	def set_TaskId(self,TaskId):
-		self.add_query_param('TaskId',TaskId)
\ No newline at end of file
+	def set_TaskId(self, TaskId):  # Long
+		self.add_query_param('TaskId', TaskId)
+	def get_ChannelId(self): # String
+		return self.get_query_params().get('ChannelId')
+
+	def set_ChannelId(self, ChannelId):  # String
+		self.add_query_param('ChannelId', ChannelId)
