@@ -25,86 +25,74 @@ class ListTenantNameRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'UniMkt', '2018-12-12', 'ListTenantName')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EndCreateTime(self):
+	def get_EndCreateTime(self): # Long
 		return self.get_query_params().get('EndCreateTime')
 
-	def set_EndCreateTime(self,EndCreateTime):
-		self.add_query_param('EndCreateTime',EndCreateTime)
-
-	def get_Business(self):
+	def set_EndCreateTime(self, EndCreateTime):  # Long
+		self.add_query_param('EndCreateTime', EndCreateTime)
+	def get_Business(self): # String
 		return self.get_query_params().get('Business')
 
-	def set_Business(self,Business):
-		self.add_query_param('Business',Business)
-
-	def get_UserId(self):
+	def set_Business(self, Business):  # String
+		self.add_query_param('Business', Business)
+	def get_UserId(self): # String
 		return self.get_query_params().get('UserId')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_OriginSiteUserId(self):
+	def set_UserId(self, UserId):  # String
+		self.add_query_param('UserId', UserId)
+	def get_OriginSiteUserId(self): # String
 		return self.get_query_params().get('OriginSiteUserId')
 
-	def set_OriginSiteUserId(self,OriginSiteUserId):
-		self.add_query_param('OriginSiteUserId',OriginSiteUserId)
-
-	def get_PageNumber(self):
+	def set_OriginSiteUserId(self, OriginSiteUserId):  # String
+		self.add_query_param('OriginSiteUserId', OriginSiteUserId)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_Environment(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_Environment(self): # String
 		return self.get_query_params().get('Environment')
 
-	def set_Environment(self,Environment):
-		self.add_query_param('Environment',Environment)
-
-	def get_AppName(self):
+	def set_Environment(self, Environment):  # String
+		self.add_query_param('Environment', Environment)
+	def get_AppName(self): # String
 		return self.get_query_params().get('AppName')
 
-	def set_AppName(self,AppName):
-		self.add_query_param('AppName',AppName)
-
-	def get_StartCreateTime(self):
+	def set_AppName(self, AppName):  # String
+		self.add_query_param('AppName', AppName)
+	def get_StartCreateTime(self): # Long
 		return self.get_query_params().get('StartCreateTime')
 
-	def set_StartCreateTime(self,StartCreateTime):
-		self.add_query_param('StartCreateTime',StartCreateTime)
-
-	def get_TenantId(self):
+	def set_StartCreateTime(self, StartCreateTime):  # Long
+		self.add_query_param('StartCreateTime', StartCreateTime)
+	def get_TenantId(self): # String
 		return self.get_query_params().get('TenantId')
 
-	def set_TenantId(self,TenantId):
-		self.add_query_param('TenantId',TenantId)
-
-	def get_PageSize(self):
+	def set_TenantId(self, TenantId):  # String
+		self.add_query_param('TenantId', TenantId)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_UserSite(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_UserSite(self): # String
 		return self.get_query_params().get('UserSite')
 
-	def set_UserSite(self,UserSite):
-		self.add_query_param('UserSite',UserSite)
-
-	def get_TenantName(self):
+	def set_UserSite(self, UserSite):  # String
+		self.add_query_param('UserSite', UserSite)
+	def get_TenantName(self): # String
 		return self.get_query_params().get('TenantName')
 
-	def set_TenantName(self,TenantName):
-		self.add_query_param('TenantName',TenantName)
-
-	def get_Status(self):
+	def set_TenantName(self, TenantName):  # String
+		self.add_query_param('TenantName', TenantName)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
