@@ -25,38 +25,39 @@ class QueryContentListRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'UniMkt', '2018-12-12', 'QueryContentList')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TaskType(self):
+	def get_TaskType(self): # String
 		return self.get_query_params().get('TaskType')
 
-	def set_TaskType(self,TaskType):
-		self.add_query_param('TaskType',TaskType)
-
-	def get_TaskBizType(self):
+	def set_TaskType(self, TaskType):  # String
+		self.add_query_param('TaskType', TaskType)
+	def get_TaskBizType(self): # String
 		return self.get_query_params().get('TaskBizType')
 
-	def set_TaskBizType(self,TaskBizType):
-		self.add_query_param('TaskBizType',TaskBizType)
-
-	def get_BrandUserId(self):
+	def set_TaskBizType(self, TaskBizType):  # String
+		self.add_query_param('TaskBizType', TaskBizType)
+	def get_BrandUserId(self): # Long
 		return self.get_query_params().get('BrandUserId')
 
-	def set_BrandUserId(self,BrandUserId):
-		self.add_query_param('BrandUserId',BrandUserId)
+	def set_BrandUserId(self, BrandUserId):  # Long
+		self.add_query_param('BrandUserId', BrandUserId)
+	def get_BrandUserNick(self): # String
+		return self.get_query_params().get('BrandUserNick')
 
-	def get_ProxyUserId(self):
+	def set_BrandUserNick(self, BrandUserNick):  # String
+		self.add_query_param('BrandUserNick', BrandUserNick)
+	def get_ProxyUserId(self): # Long
 		return self.get_query_params().get('ProxyUserId')
 
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
-
-	def get_ChannelId(self):
+	def set_ProxyUserId(self, ProxyUserId):  # Long
+		self.add_query_param('ProxyUserId', ProxyUserId)
+	def get_ChannelId(self): # String
 		return self.get_query_params().get('ChannelId')
 
-	def set_ChannelId(self,ChannelId):
-		self.add_query_param('ChannelId',ChannelId)
\ No newline at end of file
+	def set_ChannelId(self, ChannelId):  # String
+		self.add_query_param('ChannelId', ChannelId)
