@@ -25,32 +25,29 @@ class ReduceAmountRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'UniMkt', '2018-12-12', 'ReduceAmount')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Amount(self):
+	def get_Amount(self): # Long
 		return self.get_query_params().get('Amount')
 
-	def set_Amount(self,Amount):
-		self.add_query_param('Amount',Amount)
-
-	def get_V(self):
+	def set_Amount(self, Amount):  # Long
+		self.add_query_param('Amount', Amount)
+	def get_V(self): # String
 		return self.get_query_params().get('V')
 
-	def set_V(self,V):
-		self.add_query_param('V',V)
-
-	def get_TaskId(self):
+	def set_V(self, V):  # String
+		self.add_query_param('V', V)
+	def get_TaskId(self): # Long
 		return self.get_query_params().get('TaskId')
 
-	def set_TaskId(self,TaskId):
-		self.add_query_param('TaskId',TaskId)
-
-	def get_ChannelId(self):
+	def set_TaskId(self, TaskId):  # Long
+		self.add_query_param('TaskId', TaskId)
+	def get_ChannelId(self): # String
 		return self.get_query_params().get('ChannelId')
 
-	def set_ChannelId(self,ChannelId):
-		self.add_query_param('ChannelId',ChannelId)
\ No newline at end of file
+	def set_ChannelId(self, ChannelId):  # String
+		self.add_query_param('ChannelId', ChannelId)
